import gspread
from oauth2client.service_account import ServiceAccountCredentials
import pandas as pd
import datetime


class AccessLexploreMaintenanceLog(object):

    def __init__(self, authpath, sheetkey):
        # use creds to create a client to interact with the Google Drive API
        scope = ['https://spreadsheets.google.com/feeds']
        creds = ServiceAccountCredentials.from_json_keyfile_name(authpath, scope)
        client = gspread.authorize(creds)

        # Find a workbook by name and open the first sheet
        # Make sure you use the right name here.
        sheet = client.open_by_key(sheetkey).sheet1

        # Extract and print all of the values
        self.data = sheet.get_all_records()
        self.df = pd.DataFrame(sheet.get_all_records())
        self.df["start_time"] = pd.to_datetime(self.df['Date'] + ' ' + self.df['Time of arrival'], format='%d/%m/%Y %H:%M:%S', errors='coerce')
        self.df["end_time"] = pd.to_datetime(self.df['Date'] + ' ' + self.df['Time of departure'], format='%d/%m/%Y %H:%M:%S', errors='coerce')

    def was_maintenance(self, date):
        if isinstance(date, datetime.datetime):
            selection = self.df.loc[(date >= self.df['start_time']) & (date <= self.df['end_time'])]
            if len(selection) == 0:
                return False
            else:
                return selection
        else:
            raise Exception("Sorry, input date must be of type: datetime")
